@@ -26,13 +26,17 @@ Maintainer/Programmer: Roman Lefler
 
 Contributors: Davide Murtas
 
-Brazilian Portuguese (Português do Brasil): Alzemand
+Brazilian Portuguese (Português do Brasil): Alzemand, André Fernandes
 Bulgarian (български език): Lyubomir Vasilev
-Chinese (中文): know-nothing-but-123
+Chinese (中文): know-nothing-but-123, JiaoxianDu
+Dutch (Nederlands): hidenosuke
 French (Français): Samuel St. Jean, mdouchin, & Neo-29
 German (Deutsch): Ahmet Ala
 Indonesian (Bahasa Indonesia): Fakhrul Rijal
 Italian (Italiano): Davide Murtas
+Japanese (日本語): hidenosuke
+Portugese (Português): André Fernandes
+Russian (Русский): Valetss
 Turkish (Türkçe): Ahmet Ala
 
 `;
\ No newline at end of file
